# Generated by roxygen2: do not edit by hand

S3method(summary,fcmTFN)
export(cluster_assignment)
export(cluster_size)
export(fcmTFN)
export(membership)
export(membership_quality)
export(plot_dictionary)
export(plot_prototypes)
export(plot_xb)
export(print_fcmTFN)
export(prototype_results)
importFrom(graphics,axis)
importFrom(graphics,box)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,segments)
importFrom(graphics,text)
importFrom(stats,runif)
